pub fn compress(
data: &[u16],
result: &mut [u8],
config: &AztecConfig,
) -> Result<usize, AztecError>Expand description
Compress the given data
The result buffer should be at least 3 times the length (1.5 times the size in memory) of the source buffer to account for the worst case scenario where every sample is a line/slope